# Concepts overview

Read the concept documents to learn more about uv's features:

- [Projects](./projects/index.md)
- [Tools](./tools.md)
- [Python versions](./python-versions.md)
- [Resolution](./resolution.md)
- [Caching](./cache.md)

Looking for a quick introduction to features? See the [guides](../guides/index.md) instead.
